"""URLs for the time_out app."""
# from django.conf.urls.defaults import patterns, url

# from . import views


# urlpatterns = patterns(
#     '',
#     url(r'^$',
#         views.YourView.as_view(),
#         name='time_out_default'),
# )
