<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
"http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
    <title>Site is down for maintenance!</title>
</head>
<body>
<h1>Scheduled Maintenance</h1>
<p>Site is down for scheduled maintenance from <b>{{ maintenance.start_time }}</b>
    to <b>{{ maintenance.end_time }}</b> </p>
</body>
</html>